@@ -12,13 +12,13 @@ from dpymenus.exceptions import ButtonsError, CallbackError, PagesError
 class Poll(ButtonMenu):
     """Represents a Poll menu.
 
-    Attributes
-        :ctx: A reference to the command context.
-        :timeout: How long (in seconds) before the poll ends.
+    :param ctx: A reference to the command context.
+    :param timeout: How long (in seconds) before the poll ends.
+    :param destination: Whether the menu will open in the current channel, sent to a seperate guild channel, or sent to a DM channel.
     """
 
-    def __init__(self, ctx: Context, timeout: int = 300):
-        super().__init__(ctx, timeout)
+    def __init__(self, ctx: Context, **kwargs):
+        super().__init__(ctx, **kwargs)
         self.voted: Set[User] = set()
 
     def __repr__(self):
@@ -35,7 +35,7 @@ class Poll(ButtonMenu):
 
         await self._set_data()
 
-        self.output = await self.ctx.send(embed=self.page)
+        self.output = await self.destination.send(embed=self.page)
         await self._add_buttons()
 
         pending = set()
